# "Hello, World!" in een container
Installeer eerst Docker Desktop op je systeem via [deze link](https://www.docker.com/get-started/). Je mag, zoals in het filmpje vermeld wordt, Docker commando's ook in PowerShell uitvoeren.

Voer voor deze opdracht volgend commando uit (in PowerShell of in de standaardshell van MacOS): `docker run hello-world`.

Mogelijk krijg je dit, gevolgd door nog wat tekst:

```text
Hello from Docker!
This message shows that your installation appears to be working correctly.
```

Zo ja, dan mag je deze opdracht markeren als afgewerkt. Zo nee, neem dan een screenshot en vraag via het vragenforum om hulp.